@@ -2,17 +2,12 @@
 #define CPURESAMPLEIMAGEKERNEL_H
 
 #include "ResampleImageKernel.h"
-#include "Content.h"
+#include "AladinContent.h"
 
 class CPUResampleImageKernel : public ResampleImageKernel
 {
     public:
-        CPUResampleImageKernel(Content *con, std::string name) : ResampleImageKernel( name) {
-            floatingImage = con->getCurrentFloating();
-            warpedImage = con->getCurrentWarped();
-            deformationField = con->getCurrentDeformationField();
-            mask = con->getCurrentReferenceMask();
-        }
+        CPUResampleImageKernel(AladinContent *con, std::string name);
 
         nifti_image *floatingImage;
         nifti_image *warpedImage;
